==> nextcloud-app-tasks-0.13.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/mk.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Важно",
    "Today" : "Денес",
    "Week" : "Седмица",
    "All" : "Сите",
    "Current" : "Моменталлни",
    "Completed" : "Завршено",
    "Tasks" : "Задачи",
    "New List" : "Нова листа",
    "Cancel" : "Откажи",
    "Save" : "Сними",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "can edit" : "може да се измени",
    "Unable to delete the share." : "Неможе да се избрише споделениот контакт",
    "Unable to change permissions." : "Неможе да се променат дозволите.",
    "Edit" : "Уреди",
    "Copy private link" : "Копирај приватен линк",
    "Copied" : "Копирано",
    "Can not copy" : "Неможе да се копира",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "Unshare" : "Отстрани споделување",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "Hidden" : "Сокриен",
    "Visible" : "Видлив",
    "Automatic" : "Автоматски",
    "No errors" : "Нема грешки",
    "Open your browser console for more details" : "Отворете ја конзолата на прелистувачот за повеќе детали",
    "Last modified" : "Скоро изменети",
    "Priority" : "Приоритет",
    "[Yesterday]" : "[Вчера]",
    "[Today]" : "[Денес]",
    "[Tomorrow]" : "[Утре]",
    "Tomorrow" : "Утре",
    "Set start date" : "Постави почетен датум",
    "Set due date" : "Постави краен рок",
    "All day" : "Сите денови",
    "Add this as a new category" : "Додади како нова категорија",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделено покажи зафатен",
    "An error occurred" : "Настана грешка"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-tasks-0.13.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/mk.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Важно",
    "Today" : "Денес",
    "Week" : "Седмица",
    "All" : "Сите",
    "Current" : "Моменталлни",
    "Completed" : "Завршено",
    "Tasks" : "Задачи",
    "New List" : "Нова листа",
    "Cancel" : "Откажи",
    "Save" : "Сними",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "can edit" : "може да се измени",
    "Unable to delete the share." : "Неможе да се избрише споделениот контакт",
    "Unable to change permissions." : "Неможе да се променат дозволите.",
    "Edit" : "Уреди",
    "Copy private link" : "Копирај приватен линк",
    "Copied" : "Копирано",
    "Can not copy" : "Неможе да се копира",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "Unshare" : "Отстрани споделување",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "Hidden" : "Сокриен",
    "Visible" : "Видлив",
    "Automatic" : "Автоматски",
    "No errors" : "Нема грешки",
    "Open your browser console for more details" : "Отворете ја конзолата на прелистувачот за повеќе детали",
    "Due date" : "До датум",
    "Last modified" : "Скоро изменети",
    "Priority" : "Приоритет",
    "Alphabetically" : "Азбучно",
    "[Yesterday]" : "[Вчера]",
    "[Today]" : "[Денес]",
    "[Tomorrow]" : "[Утре]",
    "Tomorrow" : "Утре",
    "Set start date" : "Постави почетен датум",
    "Set due date" : "Постави краен рок",
    "All day" : "Цели денови",
    "Add this as a new category" : "Додади како нова категорија",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделен, прикажи зафатено",
    "When shared hide this event" : "Кога е споделен, сокриј го настанот",
    "Canceled" : "Откажано",
    "An error occurred" : "Настана грешка"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
